gnutls-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[SCM] GNU gnutls branch, master, updated. gnutls_2_9_10-24-ga4d4458


From: Simon Josefsson
Subject: [SCM] GNU gnutls branch, master, updated. gnutls_2_9_10-24-ga4d4458
Date: Mon, 03 May 2010 14:07:40 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU gnutls".

http://git.savannah.gnu.org/cgit/gnutls.git/commit/?id=a4d4458cf2ec080eb7e563bbd605645ac101bc92

The branch, master has been updated
       via  a4d4458cf2ec080eb7e563bbd605645ac101bc92 (commit)
      from  4ceabba9547dc3e4af1d20d26b7d1ee535d1b78b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit a4d4458cf2ec080eb7e563bbd605645ac101bc92
Author: Simon Josefsson <address@hidden>
Date:   Mon May 3 16:07:35 2010 +0200

    tests: Add srn3 to test inverse of what srn1 is testing.

-----------------------------------------------------------------------

Summary of changes:
 tests/safe-renegotiation/Makefile.am        |    2 +-
 tests/safe-renegotiation/srn1.c             |    3 ++-
 tests/safe-renegotiation/{srn1.c => srn3.c} |   11 ++++++-----
 3 files changed, 9 insertions(+), 7 deletions(-)
 copy tests/safe-renegotiation/{srn1.c => srn3.c} (94%)

diff --git a/tests/safe-renegotiation/Makefile.am 
b/tests/safe-renegotiation/Makefile.am
index 8fb85fd..2c300f0 100644
--- a/tests/safe-renegotiation/Makefile.am
+++ b/tests/safe-renegotiation/Makefile.am
@@ -25,7 +25,7 @@ AM_CPPFLAGS = \
 AM_LDFLAGS = -no-install
 LDADD = ../../lib/libgnutls.la $(LTLIBGCRYPT) $(LIBSOCKET)
 
-ctests = srn1 srn2
+ctests = srn1 srn2 srn3
 
 check_PROGRAMS = $(ctests)
 TESTS = $(ctests)
diff --git a/tests/safe-renegotiation/srn1.c b/tests/safe-renegotiation/srn1.c
index 7e660b9..992d24f 100644
--- a/tests/safe-renegotiation/srn1.c
+++ b/tests/safe-renegotiation/srn1.c
@@ -23,7 +23,8 @@
 /* Code based on ../mini-x509.c.
  *
  * This tests that a %INITIAL_SAFE_RENEGOTIATION server will reject
- * handshakes against clients that do not support the extension.
+ * handshakes against clients that do not support the extension.  This
+ * is sort of the inverse of what srn3.c is testing.
  */
 
 #ifdef HAVE_CONFIG_H
diff --git a/tests/safe-renegotiation/srn1.c b/tests/safe-renegotiation/srn3.c
similarity index 94%
copy from tests/safe-renegotiation/srn1.c
copy to tests/safe-renegotiation/srn3.c
index 7e660b9..2848ffa 100644
--- a/tests/safe-renegotiation/srn1.c
+++ b/tests/safe-renegotiation/srn3.c
@@ -22,8 +22,9 @@
 
 /* Code based on ../mini-x509.c.
  *
  * This tests that a %INITIAL_SAFE_RENEGOTIATION server will reject
  * handshakes against clients that do not support the extension.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -183,7 +184,7 @@ main (int argc, char *argv[])
                                       GNUTLS_X509_FMT_PEM);
   gnutls_init (&server, GNUTLS_SERVER);
   gnutls_credentials_set (server, GNUTLS_CRD_CERTIFICATE, serverx509cred);
-  gnutls_priority_set_direct (server, "NORMAL:%INITIAL_SAFE_RENEGOTIATION",
+  gnutls_priority_set_direct (server, "NORMAL:%DISABLE_SAFE_RENEGOTIATION",
                              NULL);
   gnutls_transport_set_push_function (server, server_push);
   gnutls_transport_set_pull_function (server, server_pull);
@@ -192,7 +193,7 @@ main (int argc, char *argv[])
   gnutls_certificate_allocate_credentials (&clientx509cred);
   gnutls_init (&client, GNUTLS_CLIENT);
   gnutls_credentials_set (client, GNUTLS_CRD_CERTIFICATE, clientx509cred);
-  gnutls_priority_set_direct (client, "NORMAL:%DISABLE_SAFE_RENEGOTIATION",
+  gnutls_priority_set_direct (client, "NORMAL:%SAFE_RENEGOTIATION",
                              NULL);
   gnutls_transport_set_push_function (client, client_push);
   gnutls_transport_set_pull_function (client, client_pull);
@@ -236,7 +237,7 @@ main (int argc, char *argv[])
   while ((cret == GNUTLS_E_AGAIN || cret == GNUTLS_E_SUCCESS)
         && (sret == GNUTLS_E_AGAIN || sret == GNUTLS_E_SUCCESS));
 
-  if (cret != GNUTLS_E_SUCCESS && sret != GNUTLS_E_SAFE_RENEGOTIATION_FAILED)
+  if (cret != GNUTLS_E_SAFE_RENEGOTIATION_FAILED && sret != GNUTLS_E_SUCCESS)
     exit_code = EXIT_FAILURE;
 
   gnutls_bye (client, GNUTLS_SHUT_RDWR);
@@ -22,8 +22,9 @@
 /* Code based on ../mini-x509.c.
  *
- * This tests that a %INITIAL_SAFE_RENEGOTIATION server will reject
- * handshakes against clients that do not support the extension.
+ * This tests that a %SAFE_RENEGOTIATION client will reject handshakes
+ * against servers that do not support the extension.  This is sort of
+ * the inverse of what srn1.c is testing.
  */
 


hooks/post-receive
-- 
GNU gnutls




reply via email to

[Prev in Thread] Current Thread [Next in Thread]